@@ -7,7 +7,7 @@ class Client(object):
     def __init__(self):
         self.api_key = None
         self.sites = Sites(self)
-        self.client = Client(self)
+        self.equipment = Equipment(self)
 
     def set_api_key(self, api_key):
         self.api_key = api_key
